@@ -3,10 +3,12 @@
 #include <stdlib.h> // for NULL
 #include <R_ext/Rdynload.h>
 
-extern SEXP C_unnest(SEXP x, SEXP lspec, SEXP dedupe, SEXP stack_atomic, SEXP rep_to_max);
+extern SEXP C_unnest(SEXP x, SEXP lspec, SEXP dedupe,
+                     SEXP stack_atomic, SEXP unnamed_lists,
+                     SEXP process_atomic, SEXP rep_to_max);
 
 static const R_CallMethodDef CallEntries[] = {
-  {"C_unnest", (DL_FUNC) &C_unnest, 5},
+  {"C_unnest", (DL_FUNC) &C_unnest, 7},
   {NULL, NULL, 0}
 };
 
